Welcome to intake_xarray's documentation!
================================================

This package enables the set of data-loading methods from Xarray to be used within the Intake
data access and cataloging system.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart.rst
   api.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
